/*
 * This code gathers data on Internet Radio Stations
 * based on their genre, codec and bitrate.
 *
 * Concept, Design and Implementation by: Craig A. Lindley
 * Last Update: 11/21/2023
 */

#ifndef AJSONLISTENER
#define AJSONLISTENER

#include <string>
#include <vector>

#include "JsonListener.h"

class AJsonListener : public JsonListener {

public:
  void whitespace(char c) {
    // Serial.println("whitespace");
  }

  void startDocument() {
    // Serial.println("start document");
  }

  void startObject() {
    // Serial.println("start object");
  }

  void startArray() {
    // Serial.println("start array");
  }

  void endArray() {
    // Serial.println("end array. ");
  }

  void endObject() {
    // Serial.println("end object");
  }

  void endDocument() {
    // Serial.println("end document");
  }

  void key(String key) {
    //Serial.println("key: " + key);
    strcpy(currentKey, key.c_str());

    // Short delay seems to be required for correct parsing
    delay(1);
  }

  void value(String value) {

    if (strcmp(currentKey, "name") == 0) {
      stationNames.push_back(value.c_str());
    } else if (strcmp(currentKey, "url_resolved") == 0) {
      stationUrls.push_back(value.c_str());
    } else if (strcmp(currentKey, "country") == 0) {
      stationCountries.push_back(value.c_str());
    }
  }

  // Show all of the gathered station info
  void showData() {
    Serial.println("\nShow data\n");
    int count = stationNames.size();
    Serial.printf("Number of stations returned: %d\n", count);
    for (int i = 0; i < count; i++) {
      Serial.printf("STATION: %s, URL: %s, COUNTRY: %s\n",
                    stationNames[i].c_str(), stationUrls[i].c_str(), stationCountries[i].c_str());
    }
  }

  // Clear all of the storage vectors
  void clearVectorData() {
    stationNames.clear();
    stationUrls.clear();
    stationCountries.clear();
  }

  // Get the number of stations returned from query
  int getNumberOfStations() {
    return stationNames.size();
  }

  // Get the Internet Radio Station's name from its index
  String getStationNameFromIndex(int index) {
    return stationNames[index];
  }

  // Get the Internet Radio Station's Url from its index
  String getStationUrlFromIndex(int index) {
    return stationUrls[index];
  }

  // Get the Internet Radio Station's country from its index
  String getStationCountryFromIndex(int index) {
    return stationCountries[index];
  }

protected:

  char currentKey[100];

  // Storage for station names
  std::vector<String> stationNames;

  // Storage for station urls
  std::vector<String> stationUrls;

  // Storage for station countries
  std::vector<String> stationCountries;
};

#endif
