/*
  ESP32 Antique Radio Player - Hardware Connections

  Concept, Design and Implementation: Craig A. Lindley
  Last Update: 11/21/2023
*/

#ifndef HARDWARE_H
#define HARDWARE_H

// Pin assignments for hardware HSPI interface
#define SPI_MOSI 23
#define SPI_MISO 19
#define SPI_CLK 18

// ST7735 LCD Display Connections
// Display also connects to +5V and Gnd
// Display RST not used
#define TFT_CS 5
#define TFT_DC 12
#define TFT_BL 14
#define TFT_RST -1

// All navigation and control is done using
// two rotary encoders which require three inputs each.
// A plus and a minus input and a switch input.
// Rotary encoders have their center pin grounded and their
// plus and minus signals connected as below. One side
// of the rotary encoder's switches is also connected to
// ground.

#define VOL_RE_PLUS 26
#define VOL_RE_MINUS 27
#define VOL_RE_SW 15

#define SONGS_RE_PLUS 33
#define SONGS_RE_MINUS 25
#define SONGS_RE_SW 4

// VS1053 module also uses SPI
// So it connects to ESP32's MOSI, MISO and SCLK
// VS1053 also connects to +5 and Gnd

// VS1053 interface
#define VS_RST 13
#define VS_xDCS 21
#define VS_DREQ 17
#define VS_xCS 22
#define VS_SDCS 32

#endif
