/*
   Navigation Class 

   Integrates Rotary Encoder movements with MultiButton switch clicks
   Long clicks are currently unassigned (UA) / unused.

   Concept, Design and Implementation by: Craig A. Lindley
   Last Update: 11/21/2023
*/

#ifndef NAVIGATION_H
#define NAVIGATION_H

class Navigation {
public:
  Navigation(PinButton *pPB, RotaryEncoder *pRE)
    : _pPB(pPB), _pRE(pRE) {
  }

  // Get navigation info
  byte getNavigationDirection() {

    int dir = _pRE->readEncoderDirection();

    if (dir == +1) {
      return NAV_UP;
    } else if (dir == -1) {
      return NAV_DOWN;
    }

    if (_pPB->isSingleClick()) {
      return NAV_SELECT;
    } else if (_pPB->isDoubleClick()) {
      return NAV_BACK;
    } else if (_pPB->isLongClick()) {
      return NAV_UA;
    }
    return NAV_NONE;
  }

  // Possible navigation codes
  static const int NAV_NONE = 0;
  static const int NAV_UP = 1;
  static const int NAV_DOWN = 2;
  static const int NAV_BACK = 3;
  static const int NAV_SELECT = 4;
  static const int NAV_UA = 5;

protected:

  // Protected data
  PinButton *_pPB;
  RotaryEncoder *_pRE;
};

#endif
